import { jsx as _jsx } from "react/jsx-runtime";
import { useRef } from "react";
import { useGetContainerIds } from "../..";
import { SingleTestContainerOverview } from "./SingleTestContainerOverview";
function getTitle(numContainers, containerId, iframeUrl) {
    let title;
    if (numContainers > 1 && !iframeUrl) {
        title = `Container Id '${containerId}'`;
    }
    else if (numContainers > 1 && iframeUrl) {
        title = `Url '${iframeUrl}' - Container Id '${containerId}'`;
    }
    else if (numContainers === 1 && iframeUrl) {
        title = `Url '${iframeUrl}'`;
    }
    return title;
}
export const MultipleTestContainersOverview = ({ iframeUrl, showGroupStats = false, onAllTestsComplete, ...props }) => {
    const completedContainerStates = useRef([]);
    const containerIds = useGetContainerIds(iframeUrl);
    const singleTestContainerCompleteCallback = (containerState) => {
        const containerId = containerState.containerId;
        const completedContainerIds = new Set(completedContainerStates.current.map((state) => state.containerId));
        // Sanity check: make sure we don't add the same container state twice.
        if (completedContainerIds.has(containerId)) {
            throw new Error(`Container with ID '${containerId}' already completed.`);
        }
        completedContainerStates.current.push(containerState);
        // When all the tests from all the containers are complete, call the onAllTestsComplete callback.
        if (completedContainerStates.current.length === containerIds.length) {
            onAllTestsComplete?.(completedContainerStates.current);
        }
    };
    return _jsx("div", { ...props, children: containerIds.map((containerId) => (_jsx(SingleTestContainerOverview, { containerId: containerId, iframeUrl: iframeUrl, showGroupStats: showGroupStats, title: getTitle(containerIds.length, containerId, iframeUrl), testsCompleteCallback: singleTestContainerCompleteCallback }, containerId))) });
};
